;; Generated package description from selected-window-contrast.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "selected-window-contrast" "0.4.1.0.20260902.4" "Highlight window and cursor at switching" '((emacs "26.1")) :commit "484a21c502eb3d136008e45b36112b0fb0a77aad" :authors '(("Anoncheg" . "vitalij@gmx.com")) :maintainer '("Anoncheg" . "vitalij@gmx.com") :keywords '("color" "windows" "faces" "buffer" "background") :url "https://codeberg.org/Anoncheg/selected-window-contrast")
